@@ -183,6 +183,9 @@ class Project(flow.Object):
         
         return self.admin.users[name]
     
+    def get_users(self):
+        return self.admin.users
+    
     def get_default_file_presets(self):
         return self.admin.project_settings.default_files
 
@@ -281,48 +284,40 @@ class Project(flow.Object):
 
         return not kitsu_api.host_is_valid() or not logged_in
     
-    def log_in(self, kitsu_login, kitsu_password):
-        kitsu_api = self.kitsu_api()
-
-        self.update_kitsu_host(self.admin.kitsu.server_url.get())
-        kitsu_user_data = kitsu_api.log_in(kitsu_login, kitsu_password)
-
-        if kitsu_user_data is None:
-            return 1
-        
-        kitsu_id = kitsu_user_data['user']['id']
-
-        # Set current user
-        # user_name = self.admin.users.get_user_name(kitsu_login)
-        user = self.admin.users.get_user_by_uid(kitsu_id)
+    def log_in(self, login, password):
+        # Check if the login matches a registered user
 
+        user = self.admin.users.get_user(login)
         if user is None:
-            # Create user profile if not registered
-            user = self.admin.users.add_user(kitsu_id, kitsu_login)
+            return False
+        
+        # Authenticate to Kitsu
 
-            if user is None:
-                return 2
+        kitsu = self.kitsu_api()
+        self.update_kitsu_host(self.admin.kitsu.server_url.get())
 
-            # user_name = user.name()
+        if not kitsu.log_in(user.name(), password):
+            # Invalid credentials
+            return False
         
         self.set_user_name(user.name())
 
-        # Create user folder at first login
+        # Save authentification tokens
+        
         user_settings_folder = self.user_settings_folder()
         if not os.path.exists(user_settings_folder):
             os.makedirs(user_settings_folder)
 
-        # Save authentification tokens
-        tokens = kitsu_api.get_tokens()
+        tokens = kitsu.get_tokens()
         kitsu_config = {}
         kitsu_config['tokens'] = tokens
-        kitsu_config['kitsu_host'] = kitsu_api.get_host()
+        kitsu_config['kitsu_host'] = kitsu.get_host()
 
         if user_settings_folder is not None:
             with open('%s/kitsu_config.json' % user_settings_folder, 'w+') as f:
                 json.dump(kitsu_config, f)
 
-        return 0
+        return True
     
     def log_out(self):
         self.kitsu_api().log_out()
